#
# spec file for package python-jsonschema
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-jsonschema
Version:        3.2.0
Release:        9.3.1
Summary:        An implementation of JSON-Schema validation for Python
License:        MIT
URL:            https://github.com/Julian/jsonschema
Source:         https://files.pythonhosted.org/packages/source/j/jsonschema/jsonschema-%{version}.tar.gz
Patch0:         webcolors.patch
BuildRequires:  %{python_module Twisted}
BuildRequires:  %{python_module attrs >= 17.4.0}
BuildRequires:  %{python_module idna}
BuildRequires:  %{python_module importlib-metadata}
BuildRequires:  %{python_module jsonpointer > 1.13}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pyrsistent >= 0.14.0}
BuildRequires:  %{python_module rfc3987}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.11.0}
BuildRequires:  %{python_module strict-rfc3339}
BuildRequires:  %{python_module webcolors}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-attrs >= 17.4.0
Requires:       python-importlib-metadata
Requires:       python-pyrsistent >= 0.14.0
Requires:       python-six >= 1.11.0
Requires(post): update-alternatives
Requires(preun): update-alternatives
BuildArch:      noarch
%if %{with python2}
BuildRequires:  python2-functools32
%endif
%ifpython2
Requires:       python-functools32
%endif
%python_subpackages

%description
jsonschema is an implementation of JSON Schema (currently in Draft 3)
for Python (supporting 2.6+ including Python 3).

%prep
%setup -q -n jsonschema-%{version}
%patch0 -p1

%build
%python_build

%install
%python_install
# Remove benchmark tests
%{python_expand rm -r %{buildroot}%{$python_sitelib}/jsonschema/benchmarks %{buildroot}%{$python_sitelib}/jsonschema/tests
%fdupes %{buildroot}%{$python_sitelib}
}

# Prepare for update-alternatives usage
%python_clone -a %{buildroot}%{_bindir}/jsonschema

%check
%python_exec setup.py test --test-suite=jsonschema.tests

%post
%python_install_alternative jsonschema

%preun
%python_uninstall_alternative jsonschema

%files %{python_files}
%license COPYING
%doc README.rst
%python_alternative %{_bindir}/jsonschema
%dir %{python_sitelib}/jsonschema
%{python_sitelib}/jsonschema/*
%dir %{python_sitelib}/jsonschema-%{version}-py*.egg-info
%{python_sitelib}/jsonschema-%{version}-py*.egg-info

%changelog
* Thu Mar 12 2020 tchvatal@suse.com
- Add patch to fix build with new webcolors:
  * webcolors.patch
* Fri Nov 22 2019 arun@gmx.de
- update to version 3.2.0 (jsc#SLE-18756):
  * Added a format_nongpl setuptools extra, which installs only format
    dependencies that are non-GPL (#619).
* Sat Nov 16 2019 arun@gmx.de
- specfile:
  * be more explicit in %%files section
  * require python-importlib-metadata
- update to version 3.1.1:
  * Temporarily revert the switch to js-regex until #611 and #612 are
    resolved.
- changes from version 3.1.0:
  * Regular expressions throughout schemas now respect the ECMA 262
    dialect, as recommended by the specification (#609).
* Mon Oct 14 2019 mcepl@suse.com
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Tue Sep 17 2019 jayvdb@gmail.com
- Activate more of the test suite
- Remove tests and benchmarking from the runtime package
- Update to v3.0.2
  * Fixed a bug where 0 and False were considered equal by
    const and enum
- from v3.0.1
  * Fixed a bug where extending validators did not preserve their
    notion of which validator property contains $id information.
- from v3.0.0
  * Support for Draft 6 and Draft 7
  * Draft 7 is now the default
  * New TypeChecker object for more complex type definitions
    (and overrides)
  * Falling back to isodate for the date-time format checker is
    no longer attempted, in accordance with the specification
* Tue Apr 16 2019 mcepl@suse.com
- Add non-updating note to the SPEC file
* Mon Apr  8 2019 dmueller@suse.com
- downgrade to < 3.0.0 again to fix all openstack clients
* Thu Mar 28 2019 tchvatal@suse.com
- Update to 3.0.1:
  * Support for Draft 6 and Draft 7
  * Draft 7 is now the default
  * New TypeChecker object for more complex type definitions (and overrides)
  * Falling back to isodate for the date-time format checker is no longer attempted, in accordance with the specification
* Mon Jan 14 2019 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Wed Jan 24 2018 tchvatal@suse.com
- Add condition around the python2 code to make sure we can build
  in python3 only enviroment
* Wed Apr 19 2017 toddrme2178@gmail.com
- Source url must be https.
* Sat Apr 15 2017 toddrme2178@gmail.com
- Fix source url.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Update to 2.6.0
  * Improved performance on CPython by adding caching around ref resolution
    (#203)
- Implement single-spec version
* Mon Oct  5 2015 mcihar@suse.cz
- Adjust dependencies for Python 2.6 based SLE 11
* Mon Jun 15 2015 arun@gmx.de
- update to version 2.5.1:
  (no changelog available)
- update to version 2.5.0:
  * Improved performance on CPython by adding caching around ref
    resolution (#203)
- specfile:
  * add python-vcversioner
- drop test requirements and %%check section, which is broken
- Fix update-alternatives usage
* Sat Nov  8 2014 ledest@gmail.com
- fix bashism in pre script
* Mon Sep 15 2014 tbechtold@suse.com
- update to version 2.4.0:
  * Added a CLI (#134)
  * Added absolute path and absolute schema path to errors (#120)
  * Added ``relevance``
  * Meta-schemas are now loaded via ``pkgutil``
  * Added ``by_relevance`` and ``best_match`` (#91)
  * Fixed ``format`` to allow adding formats for non-strings (#125)
  * Fixed the ``uri`` format to reject URI references (#131)
- BuildRequires python-setuptools
- Install /usr/bin/jsonschema with update-alternatives support
* Thu Feb 13 2014 dmueller@suse.com
- remove dependency on unittest2
* Mon Oct 21 2013 dmueller@suse.com
- update to 2.2.0:
  * Compile the host name regex (#127)
  * Allow arbitrary objects to be types (#129)
  * Support RFC 3339 datetimes in conformance with the spec
  * Fixed error paths for additionalItems + items (#122)
  * Fixed wording for min / maxProperties (#117)
* Mon Jun 10 2013 dmueller@suse.com
- update to 2.0.0:
  * Added ``create`` and ``extend`` to ``jsonschema.validators``
  * Removed ``ValidatorMixin``
  * Fixed array indices ref resolution (#95)
  * Fixed unknown scheme defragmenting and handling (#102)
* Mon Apr 29 2013 dmueller@suse.com
- update to 1.3.0:
  * Better error tracebacks (#83)
  * Raise exceptions in ``ErrorTree``\s for keys not in the instance (#92)
  * More attributes for ValidationError (#86)
  * Added ``ValidatorMixin.descend``
  * Fixed bad ``RefResolutionError`` message (#82)
  * Canonicalize URIs (#70)
* Sat Apr 13 2013 toddrme2178@gmail.com
- Remove pre_checkin.sh since the two packages are not the same
* Mon Feb 25 2013 p.drouand@gmail.com
- Add python3 support
  Tests with python3 fails for instance
* Mon Feb 25 2013 p.drouand@gmail.com
- Update to version 1.0.0:
  + Support for Draft 4
  + Support for format
  + Longs are ints too!
  + Fixed a number of issues with ``$ref`` support (#66)
  + Draft4Validator is now the default
  + ``ValidationError.path`` is now in sequential order
  + Added ``ValidatorMixin``
* Thu Nov 22 2012 saschpe@suse.de
- Update to version 0.7:
  + Partial support for (JSON Pointer) $ref
  + Deprecations
  + Validator is replaced by Draft3Validator with a slightly different
    interface
  + validator(meta_validate=False)
- Changes from version 0.6:
  + Issue #30 - Wrong behavior for the dependencies property validation
  + Fix a miswritten test
* Fri Jul 27 2012 saschpe@suse.de
- Add BuildRequires: python-unittest2 for SLE-11-SP2
* Thu Jul 26 2012 saschpe@suse.de
- Initial version
